@@ -27,7 +27,7 @@
 #include <cache.h>
 #include <error_intl.h>
 #include <mem.h>
-#include <os.h>
+#include <os_interface.h>
 #include <progname.h>
 #include <symtab.h>
 #include <trace.h>
