@@ -77,6 +77,7 @@ enum
 	arglex_token_no_system,
 	arglex_token_output,
 	arglex_token_prefix,
+	arglex_token_quote_filenames,
 	arglex_token_recursive,
 	arglex_token_recursive_not,
 	arglex_token_remove_leading_path,
@@ -202,6 +203,10 @@ static	arglex_table_ty	argtab[] =
 		"-PREfix",
 		(arglex_token_ty)arglex_token_prefix,
 	},
+	{
+		"-Quote_FileNames",
+		(arglex_token_ty)arglex_token_quote_filenames,
+	},
 	{
 		"-RECursion",
 		(arglex_token_ty)arglex_token_recursive,
@@ -499,6 +504,12 @@ main(argc, argv)
 			option.escape_newline = 1;
 			break;
 
+		case arglex_token_quote_filenames:
+			if (option.quote_filenames)
+				goto duplicate;
+			option.quote_filenames = 1;
+			break;
+
 		case arglex_token_exclude:
 			arglex();
 			if (arglex_token != arglex_token_string)
