@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1991, 1992, 1993, 1994, 1995, 1997, 1998, 1999 Peter Miller;
+ *	Copyright (C) 1991, 1992, 1993, 1994, 1995, 1997, 1998, 1999, 2000 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -20,6 +20,7 @@
  * MANIFEST: functions to scan source files looking for include files
  */
 
+#include <ac/ctype.h>
 #include <ac/stddef.h>
 #include <ac/string.h>
 #include <ac/errno.h>
@@ -27,9 +28,10 @@
 
 #include <cache.h>
 #include <error_intl.h>
+#include <flatten.h>
 #include <input/file_text.h>
 #include <mem.h>
-#include <os.h>
+#include <os_interface.h>
 #include <sniff.h>
 #include <str_list.h>
 #include <trace.h>
@@ -202,154 +204,6 @@ sniff_prepare()
 }
 
 
-/*
- * NAME
- *	flatten - remove kinks from paths
- *
- * SYNOPSIS
- *	void flatten(char *);
- *
- * DESCRIPTION
- *	The flatten function is used to remove kinks
- *	from unix path named.
- *
- * ARGUMENTS
- *	path	- path to flatten
- *
- * CAVEATS
- *	It doesn't understand symbolic links.
- */
-
-static string_ty *flatten _((string_ty *));
-
-static string_ty *
-flatten(s)
-	string_ty	*s;
-{
-	static size_t	tmplen;
-	static char	*tmp;
-	char		*in;
-	char		*out;
-
-	/*
-	 * make sure tmp area is big enough
-	 */
-	trace(("flatten(s = \"%s\")\n{\n"/*}*/, s->str_text));
-	if (s->str_length > tmplen)
-	{
-		tmplen = s->str_length;
-		tmp = mem_change_size(tmp, tmplen + 1);
-	}
-
-	/*
-	 * remove multiple '/'s
-	 */
-	out = tmp;
-	for (in = s->str_text; *in; ++in)
-	{
-		if (in[0] != '/' || in[1] != '/')
-			*out++ = *in;
-	}
-	*out = 0;
-
-	/*
-	 * remove . references
-	 */
-	in = out = tmp;
-	if (*in == '/')
-		*out++ = *in++;
-	while (*in)
-	{
-		if (in[0] == '.' && !in[1])
-			break;
-		if (in[0] == '.' && in[1] == '/')
-		{
-			in += 2;
-			continue;
-		}
-		while (*in && (*out++ = *in++) != '/')
-			;
-	}
-	*out = 0;
-
-	/*
-	 * remove .. references
-	 */
-	in = out = tmp;
-	if (*in == '/')
-		*out++ = *in++;
-	while (*in)
-	{
-		if (in[0] == '.' && in[1] == '.' && !in[2])
-		{
-			if (out == tmp)
-			{
-				/* ".." -> ".." */
-				*out++ = *in++;
-				*out++ = *in++;
-				break;
-			}
-			if (out == tmp + 1)
-			{
-				/* "/.." -> "/" */
-				break;
-			}
-			--out;
-			while (out > tmp && out[-1] != '/')
-				--out;
-			break;
-		}
-		if (in[0] == '.' && in[1] == '.' && in[2] == '/')
-		{
-			if (out == tmp)
-			{
-				/* "../" -> "../" */
-				*out++ = *in++;
-				*out++ = *in++;
-				*out++ = *in++;
-				continue;
-			}
-			if (out == tmp + 1)
-			{
-				/* "/../" -> "/" */
-				in += 3;
-				continue;
-			}
-			in += 3;
-			--out;
-			while (out > tmp && out[-1] != '/')
-				--out;
-			continue;
-		}
-		while (*in && (*out++ = *in++) != '/')
-			;
-	}
-	*out = 0;
-
-	/*
-	 * remove trailing '/'
-	 */
-	if (out > tmp + 1 && out[-1] == '/')
-		*--out = 0;
-
-	/*
-	 * "" -> "."
-	 */
-	if (!*tmp)
-	{
-		tmp[0] = '.';
-		tmp[1] = 0;
-	}
-
-	/*
-	 * return a string
-	 */
-	trace(("return \"%s\";\n", tmp));
-	trace((/*{*/"}\n"));
-	return str_from_c(tmp);
-}
-
-
 /*
  * NAME
  *	resolve
@@ -888,6 +742,68 @@ sniffer(filename, prnam, result)
 }
 
 
+static void quote_filename _((FILE *, string_ty *));
+
+static void
+quote_filename(fp, s)
+	FILE		*fp;
+	string_ty	*s;
+{
+	const char	*cp;
+
+	putc('"', fp);
+	for (cp = s->str_text; *cp; ++cp)
+	{
+		int c = (unsigned char)*cp;
+		switch (c)
+		{
+		default:
+			if (isprint(c))
+				putc(c, fp);
+			else
+				fprintf(fp, "\\%03o", c);
+			break;
+
+		case '"':
+		case '\\':
+			putc('\\', fp);
+			putc(c, fp);
+			break;
+		}
+	}
+	putc('"', fp);
+}
+
+
+static void maybe_quote_filename _((FILE *, string_ty *));
+
+static void
+maybe_quote_filename(fp, s)
+	FILE		*fp;
+	string_ty	*s;
+{
+	if (option.quote_filenames)
+		quote_filename(fp, s);
+	else
+		fputs(s->str_text, fp);
+}
+
+
+static void maybe_escape_newline _((FILE *));
+
+static void
+maybe_escape_newline(fp)
+	FILE		*fp;
+{
+	if (option.escape_newline)
+	{
+		putc(' ', fp);
+		putc('\\', fp);
+	}
+	putc('\n', fp);
+}
+
+
 static void print_the_list _((FILE *, string_ty *, string_list_ty *));
 
 static void
@@ -897,30 +813,28 @@ print_the_list(fp, pfx, result)
 	string_list_ty	*result;
 {
 	size_t		j;
+	int		need_newline;
 
-	if (option.escape_newline)
+	need_newline = 0;
+	if (pfx && pfx->str_length)
 	{
-		if (pfx)
-			fprintf(fp, "%s", pfx->str_text);
-		for (j = 0; j < result->nstrings; ++j)
-		{
-			if (j || pfx)
-				fprintf(fp, " \\\n");
-			fprintf(fp, "%s", result->string[j]->str_text);
-		}
-		if (suffix)
-			fprintf(fp, " \\\n%s", suffix);
-		fprintf(fp, "\n");
+		fputs(pfx->str_text, fp);
+		need_newline = 1;
 	}
-	else
+	for (j = 0; j < result->nstrings; ++j)
 	{
-		if (pfx)
-			fprintf(fp, "%s\n", pfx->str_text);
-		for (j = 0; j < result->nstrings; ++j)
-			fprintf(fp, "%s\n", result->string[j]->str_text);
-		if (suffix)
-			fprintf(fp, "%s\n", suffix);
+		if (need_newline)
+			maybe_escape_newline(fp);
+		maybe_quote_filename(fp, result->string[j]);
+		need_newline = 1;
 	}
+	if (suffix && *suffix)
+	{
+		if (need_newline)
+			maybe_escape_newline(fp);
+		fputs(suffix, fp);
+	}
+	fputc('\n', fp);
 }
 
 
