@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1997 Peter Miller;
+ *	Copyright (C) 1997, 1999 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -43,3 +43,10 @@ manual_directory_get()
 {
 	return MANDIR;
 }
+
+
+char *
+executable_extension_get()
+{
+	return EXEEXT;
+}
