@@ -80,11 +80,11 @@ static str_hash_ty hash_load;
  *	It is important that str_hash_ty be unsigned (int or long).
  */
 
-static str_hash_ty hash_generate _((char *, size_t));
+static str_hash_ty hash_generate _((const char *, size_t));
 
 static str_hash_ty
 hash_generate(s, n)
-	char		*s;
+	const char	*s;
 	size_t		n;
 {
 	str_hash_ty	retval;
@@ -271,7 +271,7 @@ split()
 
 string_ty *
 str_from_c(s)
-	char		*s;
+	const char	*s;
 {
 	return str_n_from_c(s, strlen(s));
 }
@@ -298,7 +298,7 @@ str_from_c(s)
 
 string_ty *
 str_n_from_c(s, length)
-	char		*s;
+	const char	*s;
 	size_t		length;
 {
 	str_hash_ty	hash;
@@ -568,9 +568,13 @@ str_field(s, sep, fldnum)
 
 
 string_ty *
+#if defined(__STDC__) && __STDC__
+str_format(const char *fmt, ...)
+#else
 str_format(fmt sva_last)
-	char		*fmt;
+	const char	*fmt;
 	sva_last_decl
+#endif
 {
 	va_list		ap;
 	string_ty	*result;
@@ -586,7 +590,7 @@ str_format(fmt sva_last)
 
 string_ty *
 str_vformat(fmt, ap)
-	char		*fmt;
+	const char	*fmt;
 	va_list		ap;
 {
 	return vmprintfes(fmt, ap);
