@@ -36,7 +36,6 @@ symtab_alloc(size)
 
 	trace(("symtab_alloc(size = %d)\n{\n"/*}*/, size));
 	stp = mem_alloc(sizeof(symtab_ty));
-	stp->chain = 0;
 	stp->reap = 0;
 	stp->hash_modulus = 1 << 2; /* MUST be a power of 2 */
 	while (stp->hash_modulus < size)
@@ -205,68 +204,121 @@ symtab_query(stp, key)
 	trace(("symtab_query(stp = %08lX, key = \"%s\")\n{\n"/*}*/,
 		(long)stp, key->str_text));
 	result = 0;
-	while (stp)
+
+	index = key->str_hash & stp->hash_cutover_mask;
+	if (index < stp->hash_split)
+		index = key->str_hash & stp->hash_cutover_split_mask;
+	for (p = stp->hash_table[index]; p; p = p->overflow)
 	{
-		index = key->str_hash & stp->hash_cutover_mask;
-		if (index < stp->hash_split)
-			index = key->str_hash & stp->hash_cutover_split_mask;
-		for (p = stp->hash_table[index]; p; p = p->overflow)
+		if (str_equal(key, p->key))
 		{
-			if (str_equal(key, p->key))
-			{
-				result = p->data;
-				goto done;
-			}
+			result = p->data;
+			break;
 		}
-		stp = stp->chain;
 	}
-	done:
+
 	trace(("return %08lX;\n", (long)result));
 	trace((/*{*/"}\n"));
 	return result;
 }
 
 
+static void
+symtab_query_fuzzy_inner _((symtab_ty *, string_ty *, double *, string_ty **,
+	void **));
+
+static void
+symtab_query_fuzzy_inner(stp, key, best_weight, best_key, best_result)
+	symtab_ty	*stp;
+	string_ty	*key;
+	double		*best_weight;
+	string_ty	**best_key;
+	void		**best_result;
+{
+	str_hash_ty	index;
+	symtab_row_ty	*p;
+
+	trace(("symtab_query_fuzzy_inner(stp = %08lX, key = \"%s\")\n{\n",
+		(long)stp, key->str_text));
+
+	for (index = 0; index < stp->hash_modulus; ++index)
+	{
+		for (p = stp->hash_table[index]; p; p = p->overflow)
+		{
+			double	w;
+
+			w = fstrcmp(key->str_text, p->key->str_text);
+			if (w > *best_weight)
+			{
+				*best_key = p->key;
+				*best_weight = w;
+				*best_result = p->data;
+			}
+		}
+	}
+	trace(("}\n"));
+}
+
+
 void *
 symtab_query_fuzzy(stp, key, key_used)
 	symtab_ty	*stp;
 	string_ty	*key;
 	string_ty	**key_used;
 {
-	str_hash_ty	index;
-	symtab_row_ty	*p;
 	double		best_weight;
 	void		*best_result;
 	string_ty	*best_key;
 
-	trace(("symtab_query(stp = %08lX, key = \"%s\")\n{\n"/*}*/,
+	trace(("symtab_query(stp = %08lX, key = \"%s\")\n{\n",
 		(long)stp, key->str_text));
 	best_weight = 0.6;
 	best_result = 0;
 	best_key = 0;
-	while (stp)
-	{
-		for (index = 0; index < stp->hash_modulus; ++index)
-		{
-			for (p = stp->hash_table[index]; p; p = p->overflow)
-			{
-				double	w;
 
-				w = fstrcmp(key->str_text, p->key->str_text);
-				if (w > best_weight)
-				{
-					best_key = p->key;
-					best_weight = w;
-					best_result = p->data;
-				}
-			}
-		}
-		stp = stp->chain;
-	}
+	symtab_query_fuzzy_inner(stp, key, &best_weight, &best_key, &best_result);
+
 	if (key_used && best_key)
 		*key_used = best_key;
 	trace(("return %08lX;\n", (long)best_result));
-	trace((/*{*/"}\n"));
+	trace(("}\n"));
+	return best_result;
+}
+
+
+void *
+symtab_query_fuzzyN(stp_table, stp_length, key, key_used)
+	symtab_ty	**stp_table;
+	size_t		stp_length;
+	string_ty	*key;
+	string_ty	**key_used;
+{
+	double		best_weight;
+	void		*best_result;
+	string_ty	*best_key;
+	size_t		j;
+
+	trace(("symtab_query_fuzzyN(key = \"%s\")\n{\n", key->str_text));
+	best_weight = 0.6;
+	best_result = 0;
+	best_key = 0;
+
+	for (j = 0; j < stp_length; ++j)
+	{
+		symtab_query_fuzzy_inner
+		(
+			stp_table[j],
+			key,
+			&best_weight,
+			&best_key,
+			&best_result
+		);
+	}
+
+	if (key_used && best_key)
+		*key_used = best_key;
+	trace(("return %08lX;\n", (long)best_result));
+	trace(("}\n"));
 	return best_result;
 }
 
