@@ -75,11 +75,11 @@ static	int		changed;
  *	It is important that wstr_hash_ty be unsigned (int or long).
  */
 
-static wstr_hash_ty hash_generate _((wchar_t *, size_t));
+static wstr_hash_ty hash_generate _((const wchar_t *, size_t));
 
 static wstr_hash_ty
 hash_generate(s, n)
-	wchar_t		*s;
+	const wchar_t	*s;
 	size_t		n;
 {
 	wstr_hash_ty	retval;
@@ -226,7 +226,7 @@ split()
 
 wstring_ty *
 wstr_from_c(s)
-	char		*s;
+	const char	*s;
 {
 	return wstr_n_from_c(s, strlen(s));
 }
@@ -253,7 +253,7 @@ wstr_from_c(s)
 
 wstring_ty *
 wstr_from_wc(ws)
-	wchar_t		*ws;
+	const wchar_t	*ws;
 {
 	return wstr_n_from_wc(ws, wcslen(ws));
 }
@@ -282,7 +282,7 @@ wstr_from_wc(ws)
 
 wstring_ty *
 wstr_n_from_c(s, length)
-	char		*s;
+	const char	*s;
 	size_t		length;
 {
 #if __STDC__ >= 1
@@ -293,7 +293,7 @@ wstr_n_from_c(s, length)
 	static wchar_t	*buf;
 	static size_t	bufmax;
 	size_t		remainder;
-	char		*ip;
+	const char	*ip;
 	wchar_t		*op;
 
 	/*
@@ -524,7 +524,7 @@ wstr_to_mbs(s, result_p, result_length_p)
 
 wstring_ty *
 wstr_n_from_wc(s, length)
-	wchar_t		*s;
+	const wchar_t	*s;
 	size_t		length;
 {
 	wstr_hash_ty	hash;
