@@ -87,8 +87,9 @@
 #include <builtin/word.h>
 #include <builtin/wordlist.h>
 #include <builtin/write.h>
-#include <id.h>
 #include <id/builtin.h>
+#include <id/global.h>
+#include <symtab.h>
 
 
 /*
@@ -213,7 +214,7 @@ builtin_initialize()
 	for (fpp = func; fpp < ENDOF(func); ++fpp)
 	{
 		s = str_from_c((*fpp)->name);
-		id_assign(s, id_builtin_new(*fpp));
+		symtab_assign(id_global_stp(), s, id_builtin_new(*fpp));
 		str_free(s);
 	}
 }
