@@ -102,8 +102,9 @@
 #include <id/variable.h>
 #include <match/new_by_recip.h>
 #include <mem.h>
+#include <opcode/context.h>
 #include <option.h>
-#include <os.h>
+#include <os_interface.h>
 #include <recipe.h>
 #include <recipe/list.h>
 #include <star.h>
@@ -140,7 +141,8 @@ static	string_list_ty	cook_auto_list_nonleaf;
  */
 
 void
-cook_search_list(slp)
+cook_search_list(ocp, slp)
+	const opcode_context_ty *ocp;
 	string_list_ty	*slp;
 {
 	string_ty	*s;
@@ -150,14 +152,20 @@ cook_search_list(slp)
 	 * make sure the variable exists
 	 */
 	trace(("cook_search_list()\n{\n"/*}*/));
-	idp = id_search(id_search_list);
+	idp = opcode_context_id_search(ocp, id_search_list);
 	if (!idp)
 	{
 		string_list_constructor(slp);
 		s = str_from_c(".");
 		string_list_append(slp, s);
 		str_free(s);
-		id_assign(id_search_list, id_variable_new(slp));
+		opcode_context_id_assign
+		(
+			(opcode_context_ty *)ocp,
+			id_search_list,
+			id_variable_new(slp),
+			0
+		);
 		string_list_destructor(slp);
 	}
 
@@ -182,7 +190,13 @@ cook_search_list(slp)
 		s = str_from_c(".");
 		string_list_prepend(slp, s);
 		str_free(s);
-		id_assign(id_search_list, id_variable_new(slp));
+		opcode_context_id_assign
+		(
+			(opcode_context_ty *)ocp,
+			id_search_list,
+			id_variable_new(slp),
+			0
+		);
 	}
 	trace((/*{*/"}\n"));
 }
@@ -215,7 +229,8 @@ cook_search_list(slp)
  */
 
 time_t
-cook_mtime_oldest(path, depth_p, max_fp_depth)
+cook_mtime_oldest(ocp, path, depth_p, max_fp_depth)
+	const opcode_context_ty *ocp;
 	string_ty	*path;
 	long		*depth_p;
 	long		max_fp_depth;
@@ -239,7 +254,7 @@ cook_mtime_oldest(path, depth_p, max_fp_depth)
 
 		prv_fp = 0;
 		result = 0;
-		cook_search_list(&sl);
+		cook_search_list(ocp, &sl);
 		*depth_p = sl.nstrings;
 		for (j = 0; j < sl.nstrings; ++j)
 		{
@@ -353,7 +368,8 @@ cook_mtime_oldest(path, depth_p, max_fp_depth)
  */
 
 time_t
-cook_mtime_newest(path, depth_p, max_fp_depth)
+cook_mtime_newest(ocp, path, depth_p, max_fp_depth)
+	const opcode_context_ty *ocp;
 	string_ty	*path;
 	long		*depth_p;
 	long		max_fp_depth;
@@ -374,7 +390,7 @@ cook_mtime_newest(path, depth_p, max_fp_depth)
 
 		prv_fp = 0;
 		result = 0;
-		cook_search_list(&sl);
+		cook_search_list(ocp, &sl);
 		*depth_p = sl.nstrings;
 		for (j = 0; j < sl.nstrings; ++j)
 		{
@@ -487,7 +503,8 @@ cook_mtime_newest(path, depth_p, max_fp_depth)
  */
 
 int
-cook_mtime_resolve(output, input, start)
+cook_mtime_resolve(ocp, output, input, start)
+	const opcode_context_ty *ocp;
 	string_list_ty	*output;
 	const string_list_ty *input;
 	int		start;
@@ -498,7 +515,7 @@ cook_mtime_resolve(output, input, start)
 
 	trace(("cook_mtime_resolve(input = %08lX, output = %08lX)\n{\n"/*}*/,
 		input, output));
-	cook_search_list(&sl);
+	cook_search_list(ocp, &sl);
 	result = 0;
 	for (j = start; j < input->nstrings; ++j)
 	{
