@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1997, 1998, 1999 Peter Miller;
+ *	Copyright (C) 1997, 1998, 1999, 2000 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -48,6 +48,7 @@
 #include <itab.h>
 #include <opcode/context.h>
 #include <option.h>
+#include <os/wait.h>
 #include <recipe.h> /* for tracing */
 #include <star.h>
 #include <symtab.h>
@@ -135,6 +136,7 @@ implications_of_file(walk, gfp, uptodate)
 	int		uptodate;
 {
 	size_t		k;
+	graph_recipe_ty	*grp2;
 
 	trace(("implications_of_file(walk=%08lX, gfp=%08lX)\n{\n"/*}*/,
 		(long)walk, (long)gfp));
@@ -147,6 +149,23 @@ implications_of_file(walk, gfp, uptodate)
 		(long)gfp->input->nrecipes));
 	if (gfp->input_satisfied < gfp->input->nrecipes)
 	{
+		if (!uptodate)
+		{
+			/*
+			 * If a file is constructed by more than one
+			 * recipe, the mod-time will be updated, making
+			 * the rest of the recipes (potentially) decide
+			 * they have nothing to do.  Set their "force"
+			 * flag to make sure they do something.
+			 */
+			for (k = 0; k < gfp->input->nrecipes; ++k)
+			{
+				grp2 = gfp->input->recipe[k];
+				assert(grp2);
+				grp2->multi_forced = 1;
+			}
+		}
+
 		trace(("...come back later\n"));
 		trace((/*{*/"}\n"));
 		return;
@@ -154,14 +173,12 @@ implications_of_file(walk, gfp, uptodate)
 
 	/*
 	 * All of the input to the file are
-	 * satisfied.  Are all of the inpouts to
+	 * satisfied.  Are all of the inputs to
 	 * the implied recipes satisfied?
 	 */
 	trace(("check %ld recipe outputs\n", (long)gfp->output->nrecipes));
 	for (k = 0; k < gfp->output->nrecipes; ++k)
 	{
-		graph_recipe_ty	*grp2;
-
 		grp2 = gfp->output->recipe[k];
 		assert(grp2);
 		grp2->input_satisfied++;
@@ -608,7 +625,9 @@ graph_walk_inner(gp, func, nproc)
 			{
 			case graph_walk_status_wait:
 				assert(itp);
+				trace(("pid = %d;\n", graph_recipe_getpid(grp)));
 				itab_assign(itp, graph_recipe_getpid(grp), grp);
+				trace(("itp->load = %ld;\n", (long)itp->load));
 				break;
 
 			case graph_walk_status_error:
@@ -672,7 +691,7 @@ graph_walk_inner(gp, func, nproc)
 				struct rusage	ru;
 	
 				trace(("mark\n"));
-				pid = wait3(&exit_status, WNOHANG, &ru);
+				pid = os_wait3(&exit_status, WNOHANG, &ru);
 				trace(("pid = %d\n", pid));
 				if (pid < 0)
 				{
@@ -698,6 +717,7 @@ graph_walk_inner(gp, func, nproc)
 							*(grp->ocp->rup) = ru;
 						graph_recipe_waited(grp, exit_status);
 						itab_delete(itp, pid);
+						trace(("itp->load = %ld;\n", (long)itp->load));
 						goto run_a_recipe;
 					}
 				}
@@ -719,9 +739,9 @@ graph_walk_inner(gp, func, nproc)
 
 			trace(("mark\n"));
 #ifdef HAVE_WAIT3
-			pid = wait3(&exit_status, 0, &ru);
+			pid = os_wait3(&exit_status, 0, &ru);
 #else
-			pid = wait(&exit_status);
+			pid = os_wait(&exit_status);
 #endif
 			trace(("pid = %d\n", pid));
 			assert(pid != 0);
@@ -751,6 +771,7 @@ graph_walk_inner(gp, func, nproc)
 #endif
 				graph_recipe_waited(grp, exit_status);
 				itab_delete(itp, pid);
+				trace(("itp->load = %ld;\n", (long)itp->load));
 				goto run_a_recipe;
 			}
 		}
@@ -806,12 +827,14 @@ graph_walk(gp)
 	string_ty	*s;
 	id_ty		*idp;
 	string_list_ty	wl;
+	opcode_context_ty *ocp;
 
 	/*
 	 * see if the jobs variable is set
 	 */
 	key = str_from_c("parallel_jobs");
-	idp = id_search(key);
+	ocp = opcode_context_new(0, 0);
+	idp = opcode_context_id_search(ocp, key);
 
 	/*
 	 * extract the number of jobs
@@ -837,9 +860,10 @@ graph_walk(gp)
 	s = str_format("%d", nproc);
 	string_list_append(&wl, s);
 	str_free(s);
-	id_assign(key, id_variable_new(&wl));
+	opcode_context_id_assign(ocp, key, id_variable_new(&wl), 0);
 	string_list_destructor(&wl);
 	str_free(key);
+	opcode_context_delete(ocp);
 
 	/*
 	 * walk the graph
