@@ -63,6 +63,19 @@
 #include <stracc.h>
 #include <trace.h>
 
+/*
+ * Define this symbol if you want the original strict interpretation of
+ * the %0 patter.  I.e. it may only apprae at the start of the pattern,
+ * or immedately after a slash (/) synbol.  Relaxing this restruiction
+ * does not change the semantics of any cookbooks.  However, it means
+ * some errors will not be detected - except that most users didn't think
+ * they were errors.  E.g.
+ * 	[match_mask -I%0% [CFLAGS]]
+ *
+#define STRICT_PERCENT_0_USAGE
+ */
+
+
 #ifdef DEBUG
 enum magic_t
 {
@@ -456,6 +469,7 @@ actual_begin = %08lX)\n{\n",
 			 * pattern, or immediately following slashes.
 			 * It may not appear before a slash.
 			 */
+#ifdef STRICT_PERCENT_0_USAGE
 			if
 			(
 				(
@@ -475,6 +489,7 @@ actual_begin = %08lX)\n{\n",
 				result = -1;
 				goto ret;
 			}
+#endif /* STRICT_PERCENT_0_USAGE */
 
 			/*
 			 * It could have been seen earlier, must be
