@@ -46,7 +46,7 @@
 #include <opcode/command.h>
 #include <opcode/private.h>
 #include <option.h>
-#include <os.h>
+#include <os_interface.h>
 #include <quote.h>
 #include <star.h>
 #include <str_list.h>
@@ -119,16 +119,17 @@ echo_command(wlp)
 }
 
 
-static string_list_ty *id_var_search _((string_ty *));
+static string_list_ty *id_var_search _((opcode_context_ty *, string_ty *));
 
 static string_list_ty *
-id_var_search(key)
+id_var_search(ocp, key)
+	opcode_context_ty *ocp;
 	string_ty	*key;
 {
 	id_ty		*idp;
 	string_list_ty	*result;
 
-	idp = id_search(key);
+	idp = opcode_context_id_search(ocp, key);
 	if (!idp)
 		return 0;
 	result = id_variable_query2(idp);
@@ -211,14 +212,15 @@ chmod_and_check(fn, mode)
  */
 
 static opcode_status_ty spawn _((string_list_ty	*, string_ty *, int *,
-	string_ty *));
+	string_ty *, opcode_context_ty *));
 
 static opcode_status_ty
-spawn(args, input, pid_p, host_binding)
+spawn(args, input, pid_p, host_binding, ocp)
 	string_list_ty	*args;
 	string_ty	*input;
 	int		*pid_p;
 	string_ty	*host_binding;
+	opcode_context_ty *ocp;
 {
 	int		j;
 	int		fd;
@@ -288,7 +290,7 @@ spawn(args, input, pid_p, host_binding)
 		 */
 		if (!key)
 			key = str_from_c("parallel_rsh");
-		slp = id_var_search(key);
+		slp = id_var_search(ocp, key);
 		if (slp)
 			string_list_copy_constructor(&cmd, slp);
 		else
@@ -673,9 +675,9 @@ meter_print(rup)
 static opcode_status_ty execute _((const opcode_ty *, opcode_context_ty *));
 
 static opcode_status_ty
-execute(op, icp)
+execute(op, ocp)
 	const opcode_ty	*op;
-	opcode_context_ty *icp;
+	opcode_context_ty *ocp;
 {
 	const opcode_command_ty *this;
 	opcode_status_ty status;
@@ -695,23 +697,23 @@ execute(op, icp)
 	flags_words = 0;
 	flags = 0;
 	wlp = 0;
-	if (icp->pid)
+	if (ocp->pid)
 	{
-		icp->pid = 0;
-		wlp = icp->wlp;
-		icp->wlp = 0;
+		ocp->pid = 0;
+		wlp = ocp->wlp;
+		ocp->wlp = 0;
 		goto resume;
 	}
 	if (this->input)
 	{
 		string_list_ty	*islp;
 
-		islp = opcode_context_string_list_pop(icp);
+		islp = opcode_context_string_list_pop(ocp);
 		isp = wl2str(islp, 0, islp->nstrings - 1, (char *)0);
 		string_list_delete(islp);
 	}
-	flags_words = opcode_context_string_list_pop(icp);
-	wlp = opcode_context_string_list_pop(icp);
+	flags_words = opcode_context_string_list_pop(ocp);
+	wlp = opcode_context_string_list_pop(ocp);
 
 	/*
 	 * take care of the options
@@ -778,18 +780,18 @@ execute(op, icp)
 		 * prepare for metering
 		 */
 #ifdef HAVE_WAIT3
-		if (option_test(OPTION_METER) && !icp->rup)
-			icp->rup = mem_alloc(sizeof(struct rusage));
+		if (option_test(OPTION_METER) && !ocp->rup)
+			ocp->rup = mem_alloc(sizeof(struct rusage));
 #endif
 
 		/*
 		 * run the command
 		 */
-		status = spawn(wlp, isp, &icp->pid, icp->host_binding);
+		status = spawn(wlp, isp, &ocp->pid, ocp->host_binding, ocp);
 		if (status == opcode_status_wait)
 		{
 			trace(("...wait\n")); 
-			icp->wlp = wlp;
+			ocp->wlp = wlp;
 			wlp = 0;
 			goto done;
 		}
@@ -799,8 +801,8 @@ resume:
 #ifdef HAVE_WAIT3
 		if (option_test(OPTION_METER))
 		{
-			assert(icp->rup);
-			meter_print(icp->rup);
+			assert(ocp->rup);
+			meter_print(ocp->rup);
 		}
 #endif
 		/*
@@ -815,7 +817,7 @@ resume:
 			exit_status
 			(
 				cmd,
-				icp->exit_status,
+				ocp->exit_status,
 				option_test(OPTION_ERROK)
 			)
 		)
@@ -865,9 +867,9 @@ resume:
 static opcode_status_ty script _((const opcode_ty *, opcode_context_ty *));
 
 static opcode_status_ty
-script(op, icp)
+script(op, ocp)
 	const opcode_ty	*op;
-	opcode_context_ty *icp;
+	opcode_context_ty *ocp;
 {
 	const opcode_command_ty *this;
 	opcode_status_ty status;
@@ -886,14 +888,14 @@ script(op, icp)
 	{
 		string_list_ty	*islp;
 
-		islp = opcode_context_string_list_pop(icp);
+		islp = opcode_context_string_list_pop(ocp);
 		isp = wl2str(islp, 0, islp->nstrings - 1, (char *)0);
 		string_list_delete(islp);
 	}
 	else
 		isp = 0;
-	flags_words = opcode_context_string_list_pop(icp);
-	wlp = opcode_context_string_list_pop(icp);
+	flags_words = opcode_context_string_list_pop(ocp);
+	wlp = opcode_context_string_list_pop(ocp);
 
 	/*
 	 * set the flags
