@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1991, 1992, 1993, 1994, 1995, 1996, 1997, 1998, 1999 Peter Miller;
+ *	Copyright (C) 1991, 1992, 1993, 1994, 1995, 1996, 1997, 1998, 1999, 2000 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -39,12 +39,14 @@
 #include <ac/utime.h>
 
 #include <error_intl.h>
+#include <home_directo.h>
 #include <mem.h>
 #include <option.h>
-#include <os.h>
+#include <os_interface.h>
+#include <os/wait.h>
 #include <stat.cache.h>
-#include <trace.h>
 #include <str_list.h>
+#include <trace.h>
 
 #ifdef HAVE_GETRUSAGE
 #include <sys/resource.h>
@@ -648,7 +650,8 @@ execute(cmd, fd, errok)
 	default:
 		for (;;)
 		{
-			pid = wait(&status);
+			pid = os_waitpid(child, &status);
+			assert(pid == child || pid == -1);
 			if (pid == child)
 				return exit_status(argv[0], status, errok);
 			if (pid < 0 && errno != EINTR)
@@ -892,29 +895,14 @@ os_exists_dir(path)
 string_ty *
 os_accdir()
 {
-	static char	home[] = "HOME";
 	static string_ty *s;
 
 	if (!s)
 	{
-		char		*cp;
+		const char	*cp;
 
-		cp = getenv(home);
-		if (!cp)
-		{
-			sub_context_ty	*scp;
-
-			scp = sub_context_new();
-			sub_var_set(scp, "Name", "%s", home);
-			error_intl
-			(
-				scp,
-			       i18n("the $name environment variable is not set")
-			);
-			sub_context_delete(scp);
-			option_set_errors();
-			return 0;
-		}
+		cp = home_directory();
+		assert(cp);
 		s = str_from_c(cp);
 	}
 	return str_copy(s);
@@ -1177,7 +1165,6 @@ os_mkdir(p, echo)
 			string_ty	*tmp;
 
 			tmp = str_n_from_c(p->str_text, cp - p->str_text);
-#if defined(_SGI_SOURCE) && !defined(_ST_PAD4SZ)
 			if (os_exists_dir(tmp))
 			{
 		        	/*
@@ -1189,10 +1176,15 @@ os_mkdir(p, echo)
 				 * permission denied error for a directory
 				 * you couldn't possibly have tried to
 				 * create, because it already existed.
+				 *
+				 * The Solaris automounter pulls a similar
+				 * stunt: it says ENOSYS for indirect
+				 * top-level directories without looking
+				 * to see if the directory exists first.
+				 * Amd does not seem to suffer from this.
 				 */
 			}
 			else
-#endif
 			if (mkdir(tmp->str_text, 0777) < 0)
 			{
 				if (errno != EEXIST)
