@@ -42,16 +42,22 @@ mkdir -p $tmp/BUILD $tmp/BUILD_ROOT $tmp/RPMS/i386 \
 test "z$icon" != "z" && cp $icon $tmp/SOURCES/.
 
 here=`pwd`/$tmp
-cat > $tmp/rpmrc << fubar
-builddir: $here/BUILD
-buildroot: $here/BUILD_ROOT
-rpmdir: $here/RPMS
-sourcedir: $here/SOURCES
-specdir: $here/SPECS
-srcrpmdir: $here/SRPMS
+
+cat > $tmp/macros << fubar
+%_builddir	$here/BUILD
+%_buildroot	$here/BUILD_ROOT
+%_rpmdir	$here/RPMS
+%_sourcedir	$here/SOURCES
+%_specdir	$here/SPECS
+%_srcrpmdir	$here/SRPMS
 fubar
 
-rpm -ta --rcfile $tmp/rpmrc --verbose --verbose $2
+mac=`rpm --showrc | awk '/^macrofile/{print $3}'`
+cat > $tmp/rpmrc << fubar
+macrofiles: ${mac}:$here/macros
+fubar
+
+rpm -ta --rcfile /usr/lib/rpm/rpmrc:${tmp}/rpmrc --verbose --verbose $2
 test $? -eq 0 || exit 1
 
 exit 0
