@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1991, 1992, 1993, 1994, 1997, 1998 Peter Miller;
+ *	Copyright (C) 1991, 1992, 1993, 1994, 1997, 1998, 1999 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -20,7 +20,7 @@
  * MANIFEST: operating system start point, and parse command line arguments
  */
 
-#include <stdio.h>
+#include <ac/stdio.h>
 #include <ac/stddef.h>
 #include <ac/string.h>
 #include <ac/stdlib.h>
@@ -127,11 +127,8 @@ main(argc, argv)
 		case arglex_token_include:
 			if (arglex() != arglex_token_string)
 			{
-				sub_context_ty	*scp;
-
-				scp = sub_context_new();
-				sub_var_set(scp, "Name", "%s", arglex_token_name(arglex_token_include));
-				fatal_intl(scp, i18n("$name needs string"));
+				arg_needs_string(arglex_token_include, usage);
+				/* NOTREACHED */
 			}
 			preprocess_include(arglex_value.alv_string);
 			break;
